Data Analysis and Visualizations — BCI-Framework documentation

# Data Analysis and Visualizations

Kafka consumers and transformers with data processing and outputs.

class `bci_framework.framework.environments.visualization.` `Visualization`(core)

  Real-time data analysis and visualizations.

  `add_subwindow`() → None

    Add new patition.

  `connect`() → None

    Connect events.

  `on_focus`() → None

    Update mdiAreas.

  `reload_all`() → None

    Reload all patitions.

  `remove_all`() → None

    Remove all patitions.

  `widgets_set_enabled`() → None

    Update action buttons.